BluetoothRfcommProfileSyncTrait

Trait BluetoothRfcommProfileSyncTrait 

pub trait BluetoothRfcommProfileSyncTrait {
    // Required method
    fn connectable(&mut self) -> Result<BluetoothRfcommConnectableSync, String>;
}
Allows building an object to connect to bluetooth devices

Required Methods

fn connectable(&mut self) -> Result<BluetoothRfcommConnectableSync, String>

Get an object in order to accept a connection from or connect to a bluetooth peer

Implementors