pub trait BluetoothRfcommProfileSyncTrait {
// Required method
fn connectable(&mut self) -> Result<BluetoothRfcommConnectableSync, String>;
}Expand description
Allows building an object to connect to bluetooth devices
Required Methods
Sourcefn connectable(&mut self) -> Result<BluetoothRfcommConnectableSync, String>
fn connectable(&mut self) -> Result<BluetoothRfcommConnectableSync, String>
Get an object in order to accept a connection from or connect to a bluetooth peer